def ok():
    print("""
    
<?xml version="1.0" encoding="UTF-8"?>
<?xml-stylesheet type="text/css" href="PROG5.css"?>

<STUDENTDATA>

 <STUDENT>
  <USN>USN   : 3GN16CS002</USN>
  <NAME>NAME : ABHISHEK MALI</NAME>
  <COLLEGE>COLLEGE : GNDECB</COLLEGE>
  <BRANCH>BRANCH :CSE</BRANCH>
  <YEAR>YEAR : 2019</YEAR>
  <EMAIL>E-MAIL : abhishek@gmail.com</EMAIL>
 </STUDENT>

 <STUDENT>
  <USN>USN : 3GN16CS029</USN>
  <NAME>NAME : KESHAV POLA</NAME>
  <COLLEGE>COLLEGE : GNDECB</COLLEGE>
  <BRANCH>BRANCH :CSE</BRANCH>
  <YEAR>YEAR : 2019</YEAR>
  <EMAIL>E-MAIL : keshav@gmail.com</EMAIL>
 </STUDENT>

 <STUDENT>
  <USN>USN   : 3GN16CS027</USN>
  <NAME>NAME : KARAN DANGE</NAME>
  <COLLEGE>COLLEGE : GNDECB</COLLEGE>
  <BRANCH>BRANCH :CSE</BRANCH>
  <YEAR>YEAR : 2019</YEAR>
  <EMAIL>E-MAIL : karan@gmail.com</EMAIL>
 </STUDENT>
 
</STUDENTDATA>


    """)